@@ -1,3 +1,11 @@
+"""
+sentry.utils.manager
+~~~~~~~~~~~~~~~~~~~~
+
+:copyright: (c) 2010 by the Sentry Team, see AUTHORS for more details.
+:license: BSD, see LICENSE for more details.
+"""
+
 import datetime
 import django
 import logging
